/* ColorVariation.java

	Purpose:
		
	Description:
		
	History:
		Mon Dec 02 15:57:05 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * A configuration object to define how the color of a child varies from the
 * parent's color. The variation is distributed among the children of node.
 * For example when setting brightness, the brightness change will range from
 * the parent's original brightness on the first child, to the amount set in
 * the to setting on the last node. This allows a gradient-like color scheme
 * that sets children out from each other while highlighting the grouping on
 * treemaps and sectors on sunburst charts.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class ColorVariation extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		key,
		to
	}

	/**
	 * Returns the key of a color variation. Currently supports brightness only.
	 * <p>
	 * Default: null
	 */
	public String getKey() {
		return getAttr(Attrs.key, null).asString();
	}

	/**
	 * Sets the key of a color variation. Currently supports brightness only.
	 */
	public void setKey(String key) {
		setAttr(Attrs.key, key);
	}

	/**
	 * Returns the ending value of a color variation. The last sibling will receive this value.
	 * <p>
	 * Default: null
	 */
	public Number getTo() {
		return getAttr(Attrs.to, null).asNumber();
	}

	/**
	 * Sets the ending value of a color variation. The last sibling will receive this value.
	 */
	public void setTo(Number to) {
		setAttr(Attrs.to, to);
	}
}
