/* States.java

	Purpose:
		
	Description:
		
	History:
		Mon, Feb 10, 2014  2:29:12 PM, Created by RaymondChao

Copyright (C) 2014 Potix Corporation. All Rights Reserved.

 */
package org.zkoss.chart;

import org.zkoss.chart.plotOptions.SeriesPlotOptions;

/**
 * A wrapper object for all the series options in specific states.
 * 
 * @author RaymondChao
 */
public class States extends Optionable {
	private enum Attrs implements PlotAttribute {
		hover, inactive, normal, select
	}

	/**
	 * Returns the hover state. If null, it will create a new one.
	 */
	public State getHover() {
		State hover = (State) getAttr(Attrs.hover);
		if (hover == null) {
			hover = new State("hover");
			setHover(hover);
		}
		return hover;
	}

	/**
	 * Sets the hover state.
	 */
	public void setHover(State hover) {
		setAttr(Attrs.hover, hover);
	}

	/**
	 * Returns the opposite state of a hover for series. If null, it will create a new one.
	 * @since 7.2.1.0
	 */
	public State getInactive() {
		State inactive = (State) getAttr(Attrs.inactive);
		if (inactive == null) {
			inactive = new State("inactive");
			setInactive(inactive);
		}
		return inactive;
	}

	/**
	 * Sets the opposite state of a hover for series.
	 * @since 7.2.1.0
	 */
	public void setInactive(State inactive) {
		setAttr(Attrs.inactive, inactive);
	}

	/**
	 * Returns the normal state of a series, or for point items in column, pie and similar series.
	 * If null, it will create a new one.
	 * Currently only used for setting animation when returning to normal state from hover.
	 * @since 7.2.1.0
	 */
	public State getNormal() {
		State normal = (State) getAttr(Attrs.normal);
		if (normal == null) {
			normal = new State("normal");
			setNormal(normal);
		}
		return normal;
	}

	/**
	 * Sets the normal state of a series, or for point items in column, pie and similar series.
	 * Currently only used for setting animation when returning to normal state from hover.
	 * @since 7.2.1.0
	 */
	public void setNormal(State normal) {
		setAttr(Attrs.normal, normal);
	}

	/**
	 * Returns the appearance of the point marker when selected. In order to
	 * allow a point to be selected, set
	 * {@link SeriesPlotOptions#setAllowPointSelect(boolean)} to true.
	 */
	public State getSelect() {
		State select = (State) getAttr(Attrs.select);
		if (select == null) {
			select = new State("select");
			setSelect(select);
		}
		return select;
	}

	/**
	 * Sets the appearance of the point marker when selected. In order to
	 * allow a point to be selected, set
	 * {@link SeriesPlotOptions#setAllowPointSelect(boolean)} to true.
	 */
	public void setSelect(State select) {
		setAttr(Attrs.select, select);
	}

}
