/* DefaultFromToModel.java

	Purpose:
		
	Description:
		
	History:
		Tue Dec 10 15:15:35 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.model;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.zkoss.zul.event.ChartDataEvent;

/**
 * A default implementation of {@link FromToModel}.
 * A FromTo model is an N series of (from, to) data objects.
 *
 * @author rudyhuang 
 * @since 7.2.1.0
 */
public class DefaultFromToModel extends AbstractChartsModel implements FromToModel {
	private static final long serialVersionUID = 20191210152004L;
	protected Map<Comparable<?>, List<FromToPair>> _seriesMap = new HashMap<Comparable<?>, List<FromToPair>>(8); //(series, FromToPair)
	protected List<Comparable<?>> _seriesList = new ArrayList<Comparable<?>>();
	private boolean _autoSort = true;

	public Comparable<?> getSeries(int index) {
		return _seriesList.get(index);
	}
	
	public Collection<Comparable<?>> getSeries() {
		return _seriesList;
	}
	
	public int getDataCount(Comparable<?> series) {
		final List<FromToPair> fromToPairs =  _seriesMap.get(series);
		return fromToPairs != null ? fromToPairs.size() : 0;
	}

	public String getFrom(Comparable<?> series, int index) {
		final List<FromToPair> fromToPairs = _seriesMap.get(series);
		
		if (fromToPairs != null) {
			return fromToPairs.get(index).getFrom();
		}
		return null;
	}

	public String getTo(Comparable<?> series, int index) {
		final List<FromToPair> fromToPairs = _seriesMap.get(series);
		
		if (fromToPairs != null) {
			return fromToPairs.get(index).getTo();
		}
		return null;
	}
	
	public void setValue(Comparable<?> series, String from, String to, int index) {
		removeValue0(series, index);
		int cIndex = addValue0(series, from, to, index);
		fireEvent(ChartDataEvent.CHANGED, series, from, _seriesList.indexOf(series), cIndex, to);
	}
	
	public void addValue(Comparable<?> series, String from, String to) {
		addValue(series, from, to, -1);
	}
	
	public void addValue(Comparable<?> series, String from, String to, int index) {
		int cIndex = addValue0(series, from, to, index);
		fireEvent(ChartDataEvent.ADDED, series, from, _seriesList.indexOf(series), cIndex, to);
	}
	
	private int addValue0(Comparable<?> series, String from, String to, int index) {
		List<FromToPair> fromToPairs = _seriesMap.get(series);
		if (fromToPairs == null) {
			fromToPairs = new ArrayList<FromToPair>(15);
			_seriesMap.put(series, fromToPairs);
			_seriesList.add(series);
		}
		int i = index; 
		if (index >= 0)
			fromToPairs.add(index, new FromToPair(from, to));
		else {
			i = fromToPairs.size();
			fromToPairs.add(new FromToPair(from, to));
		}
		return i;
	}

	public void setAutoSort(boolean auto) {
		_autoSort = auto;
	}

	public boolean isAutoSort() {
		return _autoSort;
	}
	
	public void removeSeries(Comparable<?> series) {
		_seriesMap.remove(series);
		
		final int sIndex = _seriesList.indexOf(series);
		_seriesList.remove(series);
		fireEvent(ChartDataEvent.REMOVED, series, null, sIndex, -1, null);
	}
	
	public void removeValue(Comparable<?> series, int index) {
		FromToPair old = removeValue0(series, index);
		fireEvent(ChartDataEvent.REMOVED, series, null,
				_seriesList.indexOf(series), old != null ? index : -1, null);
	}
	
	private FromToPair removeValue0(Comparable<?> series, int index) {
		List<FromToPair> fromToPairs = _seriesMap.get(series);
		if (fromToPairs == null) {
			return null;
		}
		return fromToPairs.remove(index);
	}
	
	public void clear() {
		_seriesMap.clear();
		_seriesList.clear();
		fireEvent(ChartDataEvent.REMOVED, null, null, -1, -1, null);
	}
	
	//-- internal class --//
	protected static class FromToPair implements java.io.Serializable {
		private static final long serialVersionUID = 20191210152701L;
		private String _from;
		private String _to;
		
		protected FromToPair(String from, String to) {
			_from = from;
			_to = to;
		}
		
		public String getFrom() {
			return _from;
		}
		
		public String getTo() {
			return _to;
		}
	}

	
	public Object clone() {
		DefaultFromToModel clone = (DefaultFromToModel) super.clone();
		if (_seriesMap != null)
			clone._seriesMap = new HashMap<Comparable<?>, List<FromToPair>>(_seriesMap);
		if (_seriesList != null)
			clone._seriesList = new ArrayList<Comparable<?>>(_seriesList);
		return clone;
	}
}
