package org.zkoss.chart.options3D;

import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * A 3D frame options
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 * 
 * @author hanhsu
 */
public class Frame3D extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		back, bottom, front, left, right, side, top
	}

	/**
	 * Returns the options for the back panel of a {@link Frame3D}
	 * <p>
	 * Default: an instance of {@link BackPanel}.
	 */
	public BackPanel getBack() {
		BackPanel back = (BackPanel) getAttr(Attrs.back);
		if (back == null) {
			back = new BackPanel();
			setBack(back);
		}
		return back;
	}

	/**
	 * Sets the options for the back panel of a {@link Frame3D}
	 */
	public void setBack(BackPanel back) {
		setAttr(Attrs.back, back);
	}
	
	/**
	 * Returns the options for the bottom panel of a {@link Frame3D}
	 * <p>
	 * Default: an instance of {@link BottomPanel}.
	 */
	public BottomPanel getBottom() {
		BottomPanel bottom = (BottomPanel) getAttr(Attrs.bottom);
		if (bottom == null) {
			bottom = new BottomPanel();
			setBottom(bottom);
		}
		return bottom;
	}

	/**
	 * Sets the options for the bottom panel of a {@link Frame3D}
	 */
	public void setBottom(BottomPanel bottom) {
		setAttr(Attrs.bottom, bottom);
	}

	/**
	 * Returns the options for the front panel of a {@link Frame3D}
	 * <p>
	 * Default: an instance of {@link Panel3D}.
	 * @since 7.2.1.0
	 */
	public Panel3D getFront() {
		Panel3D front = (Panel3D) getAttr(Attrs.front);
		if (front == null) {
			front = new Panel3D();
			setFront(front);
		}
		return front;
	}

	/**
	 * Sets the options for the front panel of a {@link Frame3D}
	 * @since 7.2.1.0
	 */
	public void setFront(Panel3D front) {
		setAttr(Attrs.front, front);
	}

	/**
	 * Returns the options for the left panel of a {@link Frame3D}
	 * <p>
	 * Default: an instance of {@link Panel3D}.
	 * @since 7.2.1.0
	 */
	public Panel3D getLeft() {
		Panel3D left = (Panel3D) getAttr(Attrs.left);
		if (left == null) {
			left = new Panel3D();
			setLeft(left);
		}
		return left;
	}

	/**
	 * Sets the options for the left panel of a {@link Frame3D}
	 * @since 7.2.1.0
	 */
	public void setLeft(Panel3D left) {
		setAttr(Attrs.left, left);
	}

	/**
	 * Returns the options for the right panel of a {@link Frame3D}
	 * <p>
	 * Default: an instance of {@link Panel3D}.
	 * @since 7.2.1.0
	 */
	public Panel3D getRight() {
		Panel3D right = (Panel3D) getAttr(Attrs.right);
		if (right == null) {
			right = new Panel3D();
			setRight(right);
		}
		return right;
	}

	/**
	 * Sets the options for the right panel of a {@link Frame3D}
	 * @since 7.2.1.0
	 */
	public void setRight(Panel3D right) {
		setAttr(Attrs.right, right);
	}

	/**
	 * Returns the options for the side panel of a {@link Frame3D}
	 * <p>
	 * Default: an instance of {@link SidePanel}.
	 * @deprecated since 7.2.1.0. Use left or right instead.
	 */
	@Deprecated
	public SidePanel getSide() {
		SidePanel side = (SidePanel) getAttr(Attrs.side);
		if (side == null) {
			side = new SidePanel();
			setSide(side);
		}
		return side;
	}

	/**
	 * Sets the options for the side panel of a {@link Frame3D}
	 * @deprecated since 7.2.1.0. Use left or right instead.
	 */
	@Deprecated
	public void setSide(SidePanel side) {
		setAttr(Attrs.side, side);
	}

	/**
	 * Returns the options for the top panel of a {@link Frame3D}
	 * <p>
	 * Default: an instance of {@link Panel3D}.
	 * @since 7.2.1.0
	 */
	public Panel3D getTop() {
		Panel3D top = (Panel3D) getAttr(Attrs.top);
		if (top == null) {
			top = new Panel3D();
			setTop(top);
		}
		return top;
	}

	/**
	 * Sets the options for the top panel of a {@link Frame3D}
	 * @since 7.2.1.0
	 */
	public void setTop(Panel3D top) {
		setAttr(Attrs.top, top);
	}
}
