/* OrganizationPlotOptions.java

	Purpose:

	Description:

	History:
		Mon Nov 25 16:24:35 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import java.util.List;

import org.zkoss.chart.Color;
import org.zkoss.chart.Level;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.lang.Generics;

/**
 * An option for organization plot.
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class OrganizationPlotOptions extends SankeyPlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		dataLabels, // override
		hangingIndent,
		levels,
		linkColor,
		linkLineWidth,
		linkRadius,
		nodeWidth
	}

	/**
	 * Returns the option of data labels.
	 */
	public OrganizationDataLabels getDataLabels() {
		OrganizationDataLabels dataLabels = (OrganizationDataLabels) this.getAttr(Attrs.dataLabels);
		if (dataLabels == null) {
			dataLabels = new OrganizationDataLabels();
			setDataLabels(dataLabels);
		}
		return dataLabels;
	}

	/**
	 * Returns the indentation in pixels of hanging nodes, nodes which parent has layout set to hanging.
	 * <p>
	 * Default: 20
	 */
	public Number getHangingIndent() {
		return getAttr(Attrs.hangingIndent, 20).asNumber();
	}

	/**
	 * Sets the indentation in pixels of hanging nodes, nodes which parent has layout set to hanging.
	 */
	public void setHangingIndent(Number hangingIndent) {
		setAttr(Attrs.hangingIndent, hangingIndent);
	}

	/**
	 * Returns options on specific levels. Takes precedence over series options,
	 * but not point options.
	 * <p>
	 * Default: null
	 */
	public List<Level> getLevels() {
		return Generics.cast(getAttr(Attrs.levels, null).asValue());
	}

	/**
	 * Sets options on specific levels. Takes precedence over series options,
	 * but not point options.
	 */
	public void setLevels(List<Level> levels) {
		setAttr(Attrs.levels, levels);
	}

	/**
	 * Returns the color of the links between nodes.
	 * <p>
	 * Default: #666666
	 */
	public Color getLinkColor() {
		return (Color) getAttr(Attrs.linkColor, new Color("#666666")).asValue();
	}

	/**
	 * Sets the color of the links between nodes.
	 */
	public void setLinkColor(Color linkColor) {
		setAttr(Attrs.linkColor, linkColor);
	}

	/**
	 * Sets the color of the links between nodes.
	 */
	public void setLinkColor(String linkColor) {
		setLinkColor(new Color(linkColor));
	}

	/**
	 * Returns the line width of the links connecting nodes, in pixels.
	 * <p>
	 * Default: 1
	 */
	public Number getLinkLineWidth() {
		return getAttr(Attrs.linkLineWidth, 1).asNumber();
	}

	/**
	 * Sets the line width of the links connecting nodes, in pixels.
	 */
	public void setLinkLineWidth(Number linkLineWidth) {
		setAttr(Attrs.linkLineWidth, linkLineWidth);
	}

	/**
	 * Returns radius for the rounded corners of the links between nodes.
	 * <p>
	 * Default: 10
	 */
	public Number getLinkRadius() {
		return getAttr(Attrs.linkRadius, 10).asNumber();
	}

	/**
	 * Sets radius for the rounded corners of the links between nodes.
	 */
	public void setLinkRadius(Number linkRadius) {
		setAttr(Attrs.linkRadius, linkRadius);
	}

	/**
	 * In a horizontal chart, returns the width of the nodes in pixels.
	 * Node that most organization charts are vertical, so the name of this option is counterintuitive.
	 * <p>
	 * Default: 50
	 */
	public Object getNodeWidth() {
		return getAttr(Attrs.nodeWidth, 50).asNumber();
	}

	/**
	 * In a horizontal chart, sets the width of the nodes in pixels.
	 * Node that most organization charts are vertical, so the name of this option is counterintuitive.
	 */
	public void setNodeWidth(Number nodeWidth) {
		setAttr(Attrs.nodeWidth, nodeWidth);
	}

	/**
	 * In a horizontal chart, sets the width of the nodes in pixels.
	 * Node that most organization charts are vertical, so the name of this option is counterintuitive.
	 */
	public void setNodeWidth(String nodeWidth) {
		setAttr(Attrs.nodeWidth, nodeWidth);
	}
}
