/* SankeyPlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Wed Nov 27 14:55:53 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import java.util.List;

import org.zkoss.chart.Level;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.lang.Generics;

/**
 * An option for sankey plot
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class SankeyPlotOptions extends SeriesPlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		curveFactor,
		dataLabels, // override
		levels,
		linkOpacity,
		minLinkWidth,
		nodePadding
	}

	/**
	 * Higher numbers makes the links in a sankey diagram or dependency wheelrender more curved.
	 * A curveFactor of 0 makes the lines straight.
	 * <p>
	 * Default: 0.33
	 */
	public Number getCurveFactor() {
		return getAttr(Attrs.curveFactor, 0.33).asNumber();
	}

	/**
	 * Higher numbers makes the links in a sankey diagram or dependency wheelrender more curved.
	 * A curveFactor of 0 makes the lines straight.
	 */
	public void setCurveFactor(Number curveFactor) {
		setAttr(Attrs.curveFactor, curveFactor);
	}

	/**
	 * Returns the option of data labels.
	 */
	public SankeyDataLabels getDataLabels() {
		SankeyDataLabels dataLabels = (SankeyDataLabels) this.getAttr(Attrs.dataLabels);
		if (dataLabels == null) {
			dataLabels = new SankeyDataLabels();
			setDataLabels(dataLabels);
		}
		return dataLabels;
	}

	/**
	 * Set options on specific levels. Takes precedence over series options,
	 * but not point options.
	 * <p>
	 * Default: null
	 */
	public List<Level> getLevels() {
		return Generics.cast(getAttr(Attrs.levels, null).asValue());
	}

	/**
	 * @param levels
	 * @see #getLevels()
	 */
	public void setLevels(List<Level> levels) {
		setAttr(Attrs.levels, levels);
	}

	/**
	 * Returns opacity for the links between nodes in the sankey diagram.
	 * <p>
	 * Default: 0.5
	 */
	public Number getLinkOpacity() {
		return getAttr(Attrs.linkOpacity, 0.5).asNumber();
	}

	/**
	 * Sets opacity for the links between nodes in the sankey diagram.
	 */
	public void setLinkOpacity(Number linkOpacity) {
		setAttr(Attrs.linkOpacity, linkOpacity);
	}

	/**
	 * Returns the minimal width for a line of a sankey. By default, 0 values are not shown.
	 * <p>
	 * Default: 0
	 */
	public Number getMinLinkWidth() {
		return getAttr(Attrs.minLinkWidth, 0).asNumber();
	}

	/**
	 * Sets the minimal width for a line of a sankey. By default, 0 values are not shown.
	 */
	public void setMinLinkWidth(Number minLinkWidth) {
		setAttr(Attrs.minLinkWidth, minLinkWidth);
	}

	/**
	 * Returns the padding between nodes in a sankey diagram or dependency wheel, in pixels.
	 * <p>
	 * Default: 10
	 */
	public Number getNodePadding() {
		return getAttr(Attrs.nodePadding, 10).asNumber();
	}

	/**
	 * Sets the padding between nodes in a sankey diagram or dependency wheel, in pixels.
	 */
	public void setNodePadding(Number nodePadding) {
		setAttr(Attrs.nodePadding, nodePadding);
	}
}
